eprllib.ObservationFunctions.fully_shared_parameters — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.ObservationFunctions.fully_shared_parameters

## Fully Shared Parameters Policy

This module implements a fully shared parameters policy for the observation function.

The flat observation for each agent must be a numpy array and the size must be equal to all agents. To this end, a concatenation of variables is performed.

- AgentID one-hot enconde vector

- Agent state

- Actuators state (include other agents)

Classes

`fully_shared_parameters`(obs_fn_config) |